@@ -6,7 +6,7 @@ use 5.010;
 
 no if $] >= 5.018, warnings => "experimental::smartmatch";
 
-our $VERSION = '1.07';
+our $VERSION = '1.09';
 
 use Carp qw(confess cluck);
 use Encode qw(encode decode);
@@ -18,6 +18,11 @@ use XML::LibXML;
 sub new {
 	my ( $class, %opt ) = @_;
 
+	$opt{timeout} //= 10;
+	if ( $opt{timeout} <= 0 ) {
+		delete $opt{timeout};
+	}
+
 	my $ua  = LWP::UserAgent->new(%opt);
 	my @now = localtime( time() );
 
@@ -114,9 +119,11 @@ sub new {
 
 	$self->{xml} = $response->decoded_content;
 
-	$self->{tree} = XML::LibXML->load_xml( string => $self->{xml}, );
+	$self->{tree} = XML::LibXML->load_xml(
+		string => $self->{xml},
+	);
 
-	#	say $self->{tree}->toString(1);
+	#say $self->{tree}->toString(1);
 
 	$self->check_for_ambiguous();
 
@@ -126,9 +133,13 @@ sub new {
 sub new_from_xml {
 	my ( $class, %opt ) = @_;
 
-	my $self = { xml => $opt{xml}, };
+	my $self = {
+		xml => $opt{xml},
+	};
 
-	$self->{tree} = XML::LibXML->load_xml( string => $self->{xml}, );
+	$self->{tree} = XML::LibXML->load_xml(
+		string => $self->{xml},
+	);
 
 	return bless( $self, $class );
 }
@@ -277,6 +288,10 @@ sub results {
 	my ($self) = @_;
 	my @results;
 
+	if ( not $self->{tree} ) {
+		return;
+	}
+
 	my $xp_element = XML::LibXML::XPathExpression->new('//itdDeparture');
 
 	my $xp_date  = XML::LibXML::XPathExpression->new('./itdDateTime/itdDate');
@@ -314,14 +329,15 @@ sub results {
 		my $rdate = $e_rdate ? sprintf_date($e_rdate) : $date;
 		my $rtime = $e_rtime ? sprintf_time($e_rtime) : $time;
 
-		my $platform  = $e->getAttribute('platform');
-		my $line      = $e_line->getAttribute('number');
-		my $dest      = $e_line->getAttribute('direction');
-		my $info      = $e_info->textContent;
-		my $key       = $e_line->getAttribute('key');
-		my $countdown = $e->getAttribute('countdown');
-		my $delay     = $e_info->getAttribute('delay') // 0;
-		my $type      = $e_info->getAttribute('name');
+		my $platform      = $e->getAttribute('platform');
+		my $platform_name = $e->getAttribute('platformName');
+		my $line          = $e_line->getAttribute('number');
+		my $dest          = $e_line->getAttribute('direction');
+		my $info          = $e_info->textContent;
+		my $key           = $e_line->getAttribute('key');
+		my $countdown     = $e->getAttribute('countdown');
+		my $delay         = $e_info->getAttribute('delay') // 0;
+		my $type          = $e_info->getAttribute('name');
 
 		my $platform_is_db = 0;
 
@@ -329,27 +345,48 @@ sub results {
 		  = grep { $_->{identifier} eq $e_line->getAttribute('stateless') }
 		  @{ $self->{lines} };
 
-		if ( $platform =~ s{ ^ \# }{}ox ) {
+		# platform / platformName are inconsistent. The following cases are
+		# known:
+		#
+		# * platform="int", platformName="" : non-DB platform
+		# * platform="int", platformName="Bstg. int" : non-DB platform
+		# * platform="#int", platformName="Gleis int" : non-DB platform
+		# * platform="#int", platformName="Gleis int" : DB platform?
+		# * platform="", platformName="Gleis int" : DB platform
+		# * platform="DB", platformName="Gleis int" : DB platform
+		# * platform="gibberish", platformName="Gleis int" : DB platform
+
+		if ( ( $platform_name and $platform_name =~ m{ ^ Gleis }ox )
+			and not( $platform and $platform =~ s{ ^ \# }{}ox ) )
+		{
 			$platform_is_db = 1;
 		}
 
+		if ( $platform_name and $platform_name =~ m{ ^ (Gleis | Bstg\.)}ox ) {
+			$platform = ( split( / /, $platform_name ) )[1];
+		}
+		elsif ( $platform_name and not $platform ) {
+			$platform = $platform_name;
+		}
+
 		push(
 			@results,
 			Travel::Status::DE::EFA::Result->new(
-				date        => $rdate,
-				time        => $rtime,
-				platform    => $platform,
-				platform_db => $platform_is_db,
-				key         => $key,
-				lineref     => $line_obj[0] // undef,
-				line        => $line,
-				destination => decode( 'UTF-8', $dest ),
-				countdown   => $countdown,
-				info        => decode( 'UTF-8', $info ),
-				delay       => $delay,
-				sched_date  => $date,
-				sched_time  => $time,
-				type        => $type,
+				date          => $rdate,
+				time          => $rtime,
+				platform      => $platform,
+				platform_db   => $platform_is_db,
+				platform_name => $platform_name,
+				key           => $key,
+				lineref       => $line_obj[0] // undef,
+				line          => $line,
+				destination   => decode( 'UTF-8', $dest ),
+				countdown     => $countdown,
+				info          => decode( 'UTF-8', $info ),
+				delay         => $delay,
+				sched_date    => $date,
+				sched_time    => $time,
+				type          => $type,
 			)
 		);
 	}
@@ -382,14 +419,14 @@ Travel::Status::DE::EFA - unofficial EFA departure monitor
 
     for my $d ($status->results) {
         printf(
-            "%s %d %-5s %s\n",
-            $d->time, $d->platform, $d->line, $d->destination
+            "%s %-8s %-5s %s\n",
+            $d->time, $d->platform_name, $d->line, $d->destination
         );
     }
 
 =head1 VERSION
 
-version 1.07
+version 1.09
 
 =head1 DESCRIPTION
 
@@ -441,11 +478,16 @@ B<stop> (stop/station name).
 
 address / poi / stop name to list departures for.
 
+=item B<timeout> => I<seconds>
+
+Request timeout, the argument is passed on to LWP::UserAgent(3pm).
+Default: 10 seconds. Set to 0 or a negative value to disable it.
+
 =back
 
 =item $status->errstr
 
-In case of en HTTP request or EFA error, returns a string describing it. If
+In case of an HTTP request or EFA error, returns a string describing it. If
 none occured, returns undef.
 
 =item $status->lines
